# Switch Automation library for Python
This is a package for building configurable UI/UX experiences on the Switch Automation software platform. 

You can find out more about the platform on [Switch Automation](https://www.switchautomation.com)

## Getting started

### Prerequisites
* Python 3.8 or later is required to use this package. 
* You must have a [Switch Automation user account](https://www.switchautomation.com/our-solution/) to use this package. 

### Install the package
Install the Switch Guides library for Python with [pip](https://pypi.org/project/pip/):

```bash
pip install switch-guides
```